==> zio-aws-mediatailor_3-5.17.124.3-sources.jar: zio/aws/mediatailor/model/CdnConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CdnConfiguration(
    adSegmentUrlPrefix: Option[__string] = None,
    contentSegmentUrlPrefix: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.CdnConfiguration = {
    import CdnConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.CdnConfiguration
      .builder()
      .optionallyWith(
        adSegmentUrlPrefix.map(value =>
          __string.unwrap(value): java.lang.String
        )
      )(_.adSegmentUrlPrefix)
      .optionallyWith(
        contentSegmentUrlPrefix.map(value =>
          __string.unwrap(value): java.lang.String
        )
      )(_.contentSegmentUrlPrefix)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.CdnConfiguration.ReadOnly =
    zio.aws.mediatailor.model.CdnConfiguration.wrap(buildAwsValue())
}
object CdnConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.CdnConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.CdnConfiguration =
      zio.aws.mediatailor.model.CdnConfiguration(
        adSegmentUrlPrefix.map(value => value),
        contentSegmentUrlPrefix.map(value => value)
      )
    def adSegmentUrlPrefix: Option[__string]
    def contentSegmentUrlPrefix: Option[__string]
    def getAdSegmentUrlPrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("adSegmentUrlPrefix", adSegmentUrlPrefix)
    def getContentSegmentUrlPrefix: ZIO[Any, AwsError, __string] = AwsError
      .unwrapOptionField("contentSegmentUrlPrefix", contentSegmentUrlPrefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.CdnConfiguration
  ) extends zio.aws.mediatailor.model.CdnConfiguration.ReadOnly {
    override val adSegmentUrlPrefix: Option[__string] = scala
      .Option(impl.adSegmentUrlPrefix())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
    override val contentSegmentUrlPrefix: Option[__string] = scala
      .Option(impl.contentSegmentUrlPrefix())
      .map(value => zio.aws.mediatailor.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.CdnConfiguration
  ): zio.aws.mediatailor.model.CdnConfiguration.ReadOnly = new Wrapper(impl)
}

==> zio-aws-mediatailor_3-5.17.158.3-sources.jar: zio/aws/mediatailor/model/CdnConfiguration.scala <==
package zio.aws.mediatailor.model
import zio.aws.mediatailor.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class CdnConfiguration(
    adSegmentUrlPrefix: Option[__string] = None,
    contentSegmentUrlPrefix: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.mediatailor.model.CdnConfiguration = {
    import CdnConfiguration.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.mediatailor.model.CdnConfiguration
      .builder()
      .optionallyWith(adSegmentUrlPrefix.map(value => value: java.lang.String))(
        _.adSegmentUrlPrefix
      )
      .optionallyWith(
        contentSegmentUrlPrefix.map(value => value: java.lang.String)
      )(_.contentSegmentUrlPrefix)
      .build()
  }
  def asReadOnly: zio.aws.mediatailor.model.CdnConfiguration.ReadOnly =
    zio.aws.mediatailor.model.CdnConfiguration.wrap(buildAwsValue())
}
object CdnConfiguration {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.mediatailor.model.CdnConfiguration
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.mediatailor.model.CdnConfiguration =
      zio.aws.mediatailor.model.CdnConfiguration(
        adSegmentUrlPrefix.map(value => value),
        contentSegmentUrlPrefix.map(value => value)
      )
    def adSegmentUrlPrefix: Option[__string]
    def contentSegmentUrlPrefix: Option[__string]
    def getAdSegmentUrlPrefix: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("adSegmentUrlPrefix", adSegmentUrlPrefix)
    def getContentSegmentUrlPrefix: ZIO[Any, AwsError, __string] = AwsError
      .unwrapOptionField("contentSegmentUrlPrefix", contentSegmentUrlPrefix)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.mediatailor.model.CdnConfiguration
  ) extends zio.aws.mediatailor.model.CdnConfiguration.ReadOnly {
    override val adSegmentUrlPrefix: Option[__string] =
      scala.Option(impl.adSegmentUrlPrefix()).map(value => value: __string)
    override val contentSegmentUrlPrefix: Option[__string] =
      scala.Option(impl.contentSegmentUrlPrefix()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.mediatailor.model.CdnConfiguration
  ): zio.aws.mediatailor.model.CdnConfiguration.ReadOnly = new Wrapper(impl)
}
